summaryrefslogtreecommitdiff
path: root/src/roadveh.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/roadveh.h')
-rw-r--r--src/roadveh.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/roadveh.h b/src/roadveh.h
index fbc865636..06139a426 100644
--- a/src/roadveh.h
+++ b/src/roadveh.h
@@ -268,13 +268,13 @@ protected: // These functions should not be called outside acceleration code.
}
/**
* Road vehicles have to use GetSlopeZ() to compute their height
* if they are reversing because in that case, their direction
* is not parallel with the road. It is safe to return \c true
* even if it is not reversing.
* @return are we (possibly) reversing?
*/
- FORCEINLINE bool HasToUseGetSlopeZ()
+ FORCEINLINE bool HasToUseGetSlopePixelZ()
{
const RoadVehicle *rv = this->First();
@@ -268,13 +268,13 @@ protected: // These functions should not be called outside acceleration code.
}
/**
- * Road vehicles have to use GetSlopeZ() to compute their height
+ * Road vehicles have to use GetSlopePixelZ() to compute their height
* if they are reversing because in that case, their direction
* is not parallel with the road. It is safe to return \c true